import tkinter as tk
import _tkinter
from huoyanlib import _raise_huoyanerror_tcl


def make_window(size_height, size_width, title):
    window = tk.Tk()
    try:
        window.title(title)
    except _tkinter.TclError:
        _raise_huoyanerror_tcl()

    try:
        window.geometry(str(size_height) + 'x' + str(size_width))
    except _tkinter.TclError:
        _raise_huoyanerror_tcl()


#即将更新


class HuoYanError(Exception):
    """"nothing"""


def _raise_huoyanerror_object():
    raise HuoYanError('Please use the right object')


def _raise_huoyanerror_tcl():
    raise HuoYanError('this object can‘t be used in tkinter')